SystemOrganization addCategory: #'Magma seaside'!

!MagmaLocalLocation methodsFor: '*magma seaside' stamp: 'kph 6/28/2006 04:20'!
newSession
	"For local, we have to determine whether the files are already in-use by another
	local-connection.  If they are, create a new session sharing the original's
	repositoryController, Otherwise open the files."

	| sessionClass |
	sessionClass := self sessionClass.
	^ sessionClass connectedSessions
		maDetect: [ :each | each pathName = path ]
		ifFound: [ :foundSession | sessionClass repositoryController: foundSession repositoryController ]
		ifNone: [ sessionClass openLocal: self repositoryPath ]! !

!MagmaLocalLocation methodsFor: '*magma seaside' stamp: 'kph 6/28/2006 04:21'!
repositoryPath

^FileDirectory default fullNameFor: path! !

WASystemConfiguration subclass: #WAMagmaConfiguration
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magma seaside'!

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'mmb 12/5/2005 09:17'!
ancestors

	^ Array with: (WARenderLoopConfiguration new)! !

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'brp 11/4/2005 12:17'!
attributes
    "Return the attributes specific to this configuration"

	^ Array with: (WAMagmaLocationAttribute key: #location group: #magma)
! !

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'brp 11/4/2005 11:44'!
location

	^ MagmaLocalLocation default
! !

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 11:35'!
repositoryPath

	^ 'store'
! !

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 11:24'!
sessionClass

	^ WAMagmaSession! !

WASession subclass: #WAMagmaSession
	instanceVariableNames: 'magmaSession'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magma seaside'!

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 12:53'!
commit: aBlock

	self magmaSession commit: aBlock
! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 12:58'!
expire

	super expire.
	magmaSession ifNotNil: [ magmaSession disconnect. magmaSession := nil ]! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'brp 11/4/2005 12:19'!
magmaSession

	^ magmaSession ifNil: [ 
		magmaSession := (self application preferenceAt: #location) newSession.
		magmaSession connectAs: 'seaside'.
		magmaSession ]! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 12:56'!
repositoryPath
	"This is a convenience method to get the repository directory path from Seaside"

	^ FileDirectory default fullNameFor: (self application preferenceAt: #repositoryPath)! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 12:52'!
root

	^ self magmaSession root
! !

!WAConfigurationEditor methodsFor: '*magma seaside' stamp: 'kph 6/15/2006 19:13'!
renderMagmaLocationAttribute: anAttribute on: html

	| location |
	location := configuration valueForAttribute: anAttribute.

	html div id: 'location'; with: [
		html table: [
			location isLocal
				ifTrue: [
					html tableRow: [  
						html tableData id: 'label'; with: 'path:'.
						html tableData: [ html textInput on: #path of: location ]
					]
				]
				ifFalse: [
					html tableRow: [  
						html tableData id: 'label'; with: 'host'.
						html tableData: [ html textInput on: #host of: location ]
					].
					html tableRow: [  
						html tableData id: 'label'; with: 'port'.
						html tableData: [ html textInput value: location port;
								callback: [:v | location port: v asNumber] ]
					].
				]
		]
	]! !

!WAConfigurationEditor methodsFor: '*magma seaside' stamp: 'kph 6/15/2006 20:33'!
visitMagmaLocationAttribute: anAttribute with: html

	| location |
	location := configuration valueForAttribute: anAttribute. 

	html select 
		list: anAttribute options;
		selected: location class;
		beSubmitOnChange;
		labels: [ :ea | ea name ];
		callback: [ :item | 	(configuration valueAt: #location) class == item
			ifFalse: [ configuration takeValue: item default forAttribute: anAttribute. ]
 		];
		yourself.

	self renderMagmaLocationAttribute: anAttribute on: html.! !

WAConfigurationAttribute subclass: #WAMagmaLocationAttribute
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magma seaside'!

!WAMagmaLocationAttribute methodsFor: 'as yet unclassified' stamp: 'brp 11/4/2005 10:00'!
accept: aVisitor with: anObject

	^ aVisitor visitMagmaLocationAttribute: self with: anObject! !

!WAMagmaLocationAttribute methodsFor: 'as yet unclassified' stamp: 'brp 11/4/2005 12:13'!
options

	^ MagmaLocation subclasses! !
